@@ -1,8 +1,3 @@
-# Copyright (c) 2016 CentralNic Ltd. All rights reserved. This program is
-# free software; you can redistribute it and/or modify it under the same
-# terms as Perl itself.
-# 
-# $Id: Host.pm,v 1.3 2011/12/03 11:44:52 gavin Exp $
 package Net::EPP::Frame::Command::Check::Host;
 use base qw(Net::EPP::Frame::Command::Check);
 use Net::EPP::Frame::ObjectSpec;
@@ -61,12 +56,12 @@ This results in an XML document like this:
 =cut
 
 sub new {
-	my $package = shift;
-	my $self = bless($package->SUPER::new('check'), $package);
+    my $package = shift;
+    my $self    = bless($package->SUPER::new('check'), $package);
 
-	$self->addObject(Net::EPP::Frame::ObjectSpec->spec('host'));
+    $self->addObject(Net::EPP::Frame::ObjectSpec->spec('host'));
 
-	return $self;
+    return $self;
 }
 
 =pod
@@ -80,35 +75,14 @@ This adds a hostname to the list of hosts to be checked.
 =cut
 
 sub addHost {
-	my ($self, $host) = @_;
+    my ($self, $host) = @_;
 
-	my $name = $self->createElement('host:name');
-	$name->appendText($host);
+    my $name = $self->createElement('host:name');
+    $name->appendText($host);
 
-	$self->getNode('check')->getChildNodes->shift->appendChild($name);
+    $self->getNode('check')->getChildNodes->shift->appendChild($name);
 
-	return 1;
+    return 1;
 }
 
-=pod
-
-=head1 AUTHOR
-
-CentralNic Ltd (http://www.centralnic.com/).
-
-=head1 COPYRIGHT
-
-This module is (c) 2016 CentralNic Ltd. This module is free software; you can
-redistribute it and/or modify it under the same terms as Perl itself.
-
-=head1 SEE ALSO
-
-=over
-
-=item * L<Net::EPP::Frame>
-
-=back
-
-=cut
-
 1;
