@@ -1,8 +1,3 @@
-# Copyright (c) 2011 CentralNic Ltd. All rights reserved. This program is
-# free software; you can redistribute it and/or modify it under the same
-# terms as Perl itself.
-# 
-# $Id: Host.pm,v 1.3 2011/01/23 12:26:24 gavin Exp $
 package Net::EPP::Frame::Command::Delete::Host;
 use base qw(Net::EPP::Frame::Command::Delete);
 use Net::EPP::Frame::ObjectSpec;
@@ -29,7 +24,7 @@ This results in an XML document like this:
 
 	<?xml version="1.0" encoding="UTF-8"?>
 	<epp xmlns="urn:ietf:params:xml:ns:epp-1.0"
-	  xmlns:xsi="http://www.w3.org/2011/XMLSchema-instance"
+	  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
 	  xsi:schemaLocation="urn:ietf:params:xml:ns:epp-1.0
 	  epp-1.0.xsd">
 	    <command>
@@ -57,12 +52,12 @@ This results in an XML document like this:
 =cut
 
 sub new {
-	my $package = shift;
-	my $self = bless($package->SUPER::new('delete'), $package);
+    my $package = shift;
+    my $self    = bless($package->SUPER::new('delete'), $package);
 
-	my $host = $self->addObject(Net::EPP::Frame::ObjectSpec->spec('host'));
+    my $host = $self->addObject(Net::EPP::Frame::ObjectSpec->spec('host'));
 
-	return $self;
+    return $self;
 }
 
 =pod
@@ -76,35 +71,14 @@ This specifies the host object to be deleted.
 =cut
 
 sub setHost {
-	my ($self, $host) = @_;
+    my ($self, $host) = @_;
 
-	my $name = $self->createElement('host:name');
-	$name->appendText($host);
+    my $name = $self->createElement('host:name');
+    $name->appendText($host);
 
-	$self->getNode('delete')->getChildNodes->shift->appendChild($name);
+    $self->getNode('delete')->getChildNodes->shift->appendChild($name);
 
-	return 1;
+    return 1;
 }
 
-=pod
-
-=head1 AUTHOR
-
-CentralNic Ltd (http://www.centralnic.com/).
-
-=head1 COPYRIGHT
-
-This module is (c) 2011 CentralNic Ltd. This module is free software; you can
-redistribute it and/or modify it under the same terms as Perl itself.
-
-=head1 SEE ALSO
-
-=over
-
-=item * L<Net::EPP::Frame>
-
-=back
-
-=cut
-
 1;
