@@ -1,8 +1,3 @@
-# Copyright (c) 2016 CentralNic Ltd. All rights reserved. This program is
-# free software; you can redistribute it and/or modify it under the same
-# terms as Perl itself.
-# 
-# $Id: Contact.pm,v 1.4 2011/12/03 11:44:52 gavin Exp $
 package Net::EPP::Frame::Command::Info::Contact;
 use base qw(Net::EPP::Frame::Command::Info);
 use Net::EPP::Frame::ObjectSpec;
@@ -57,12 +52,12 @@ This results in an XML document like this:
 =cut
 
 sub new {
-	my $package = shift;
-	my $self = bless($package->SUPER::new('info'), $package);
+    my $package = shift;
+    my $self    = bless($package->SUPER::new('info'), $package);
 
-	my $contact = $self->addObject(Net::EPP::Frame::ObjectSpec->spec('contact'));
+    my $contact = $self->addObject(Net::EPP::Frame::ObjectSpec->spec('contact'));
 
-	return $self;
+    return $self;
 }
 
 =pod
@@ -76,35 +71,14 @@ This specifies the contact object for which information is being requested.
 =cut
 
 sub setContact {
-	my ($self, $id) = @_;
+    my ($self, $id) = @_;
 
-	my $name = $self->createElement('contact:id');
-	$name->appendText($id);
+    my $name = $self->createElement('contact:id');
+    $name->appendText($id);
 
-	$self->getNode('info')->getChildNodes->shift->appendChild($name);
+    $self->getNode('info')->getChildNodes->shift->appendChild($name);
 
-	return 1;
+    return 1;
 }
 
-=pod
-
-=head1 AUTHOR
-
-CentralNic Ltd (http://www.centralnic.com/).
-
-=head1 COPYRIGHT
-
-This module is (c) 2016 CentralNic Ltd. This module is free software; you can
-redistribute it and/or modify it under the same terms as Perl itself.
-
-=head1 SEE ALSO
-
-=over
-
-=item * L<Net::EPP::Frame>
-
-=back
-
-=cut
-
 1;
